@@ -2,8 +2,7 @@ use bevy::prelude::*;
 use bevy_obj::*;
 
 fn main() {
-    App::build()
-        .insert_resource(Msaa { samples: 4 })
+    App::new()
         .add_plugins(DefaultPlugins)
         .add_plugin(ObjPlugin)
         .add_startup_system(setup.system())
@@ -17,16 +16,19 @@ fn setup(
 ) {
     commands.spawn_bundle(PbrBundle {
         mesh: asset_server.load("cube.obj"),
-        material: materials.add(Color::rgb(0.5, 0.4, 0.3).into()),
+        material: materials.add(StandardMaterial {
+            base_color_texture: Some(asset_server.load("cube.png")),
+            ..Default::default()
+        }),
         ..Default::default()
     });
-    commands.spawn_bundle(LightBundle {
-        transform: Transform::from_translation(Vec3::new(4.0, 5.0, 4.0)),
+    commands.spawn_bundle(PointLightBundle {
+        transform: Transform::from_translation(Vec3::new(3.0, 4.0, 3.0)),
         ..Default::default()
     });
     commands.spawn_bundle(PerspectiveCameraBundle {
-        transform: Transform::from_translation(Vec3::new(1.5, 2.7, 3.0))
-            .looking_at(Vec3::new(0.0, 0.3, 0.0), Vec3::Y),
+        transform: Transform::from_translation(Vec3::new(1.5, 2.7, 4.0))
+            .looking_at(Vec3::new(0.0, 0.0, 0.0), Vec3::Y),
         ..Default::default()
     });
 }
